The pytrnsys package provides a complete framework to run, process, plot, and report
TRNSYS simulations. It is designed to give researchers a fast,
fully automatized, and easily reproducible way to execute and share TRNSYS simulations by the use of a single short
configuration file. In addition, a large variety of commands is accessible
to post-process simulation results in one shot.